@@ -9,7 +9,7 @@ except ImportError:
 
 from flask import Blueprint, render_template, abort, request, url_for, redirect, flash, Response
 from flask_peewee.forms import BooleanSelectField, ForeignKeyField, CustomModelConverter
-from flask_peewee.filters import QueryFilter, lookups_for_field, Lookup, FIELD_TYPES
+from flask_peewee.filters import QueryFilter, lookups_for_field, Lookup
 from flask_peewee.serializer import Serializer
 from flask_peewee.utils import get_next, PaginatedQuery, path_to_models, slugify
 from peewee import BooleanField, DateTimeField, ForeignKeyField, DateField
@@ -127,11 +127,12 @@ class ModelAdmin(object):
             name,
         )
 
-    def get_form(self):
-        return model_form(self.model, only=self.fields, exclude=self.exclude, converter=CustomModelConverter(self))
+    def get_form(self, adding=False):
+        allow_pk = adding and not self.model._meta.auto_increment
+        return model_form(self.model, allow_pk=allow_pk, only=self.fields, exclude=self.exclude, converter=CustomModelConverter(self))
 
     def get_add_form(self):
-        return self.get_form()
+        return self.get_form(adding=True)
 
     def get_edit_form(self):
         return self.get_form()
@@ -200,7 +201,7 @@ class ModelAdmin(object):
 
     def save_model(self, instance, form, adding=False):
         form.populate_obj(instance)
-        instance.save()
+        instance.save(force_insert=adding)
         return instance
 
     def apply_ordering(self, query, ordering):
